@@ -1,9 +1,9 @@
 package Pod::Weaver::Plugin::BorderStyle;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-19'; # DATE
+our $DATE = '2021-05-12'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-BorderStyle'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -145,21 +145,21 @@ _
                         push @pod, "\nSample output:\n\n$q_output\n" unless $bstyle_struct->{box_chars};
                     } # EXAMPLE_WITH_TEXT_ANSITABLE
 
-                  EXAMPLE_WITH_TEXT_TABLE_SPAN: {
-                        require Text::Table::Span;
-                        my $q_output = Text::Table::Span::generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>$bstyle_without_prefix) . "\n"; $q_output =~ s/^/ /gm;
+                  EXAMPLE_WITH_TEXT_TABLE_MORE: {
+                        require Text::Table::More;
+                        my $q_output = Text::Table::More::generate_table(rows=>$rows, header_row=>1, separate_rows=>1, border_style=>$bstyle_without_prefix) . "\n"; $q_output =~ s/^/ /gm;
 
                     push @pod, <<"_";
-To use with L<Text::Table::Span>:
+To use with L<Text::Table::More>:
 
- use Text::Table::Span qw/generate_table/;
+ use Text::Table::More qw/generate_table/;
  my \$rows =
 $q_rows;
  generate_table(rows=>\$rows, header_row=>1, separate_rows=>1, border_style=>$q_bstyle_without_prefix);
 
 _
                         push @pod, "\nSample output:\n\n$q_output\n" unless $bstyle_struct->{box_chars};
-                    } # EXAMPLE_WITH_TEXT_TABLE_SPAN
+                    } # EXAMPLE_WITH_TEXT_TABLE_MORE
 
                   EXAMPLE_WITH_TEXT_TABLE_TINYBORDERSTYLE: {
                         require Text::Table::TinyBorderStyle;
@@ -218,7 +218,7 @@ Pod::Weaver::Plugin::BorderStyle - Plugin to use when building distribution whic
 
 =head1 VERSION
 
-This document describes version 0.002 of Pod::Weaver::Plugin::BorderStyle (from Perl distribution Pod-Weaver-Plugin-BorderStyle), released on 2021-02-19.
+This document describes version 0.003 of Pod::Weaver::Plugin::BorderStyle (from Perl distribution Pod-Weaver-Plugin-BorderStyle), released on 2021-05-12.
 
 =head1 SYNOPSIS
 
@@ -261,7 +261,7 @@ Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Bo
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-BorderStyle/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Plugin-BorderStyle>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -279,7 +279,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
